package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````,``P`!````$!8``#0```!8L0```````#0`(``)
M`"@`&P`:``8````T````-````#0````@`0``(`$```4````$`````P```%0!
M``!4`0``5`$``!,````3````!`````$````!````````````````````6*T`
M`%BM```%`````!````$```#4K0``U+T``-2]```\`@``@!(```8`````$```
M`@```."M``#@O0``X+T``/````#P````!@````0````$````:`$``&@!``!H
M`0``1````$0````$````!````%#E=&38G@``V)X``-B>``#L````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DU*T`
M`-2]``#4O0``+`(``"P"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`>H^BH*1,7_Z!+*H&'VN?S"4'LM@1````2P````@````(`````!`0!"5`
M!(`H`0`!H(8`@(`!```+*`0).*`218H$"`@`````2P```$\```!3````5```
M`%H```!;````7````%X```!?`````````&$```!C````9````&4`````````
M`````&[%WQ_JT^\.SMY'+6M_FGPNQ9NV(/_D#KB-\0[59-1\V7%8'.)'Q@&L
M2^/`NN.2?,+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'<-,-%.*>VLWCGC-B
MV^T,.I<+6>CM['^IG)OAIP(*H^#[20````````````````````"=`@``````
M```````2````2P,`````````````$@```/(!`````````````!(````1````
M```````````@````9`,`````````````$0```,H#`````````````!(```#J
M`@`````````````1````/`,`````````````$@```!D!`````````````!(`
M``"X`@`````````````2````O```````````````$@```(L!````````````
M`!(```"D`@`````````````2````F```````````````$@```!0!````````
M`````!(```!N`P`````````````2````\0(`````````````$@````D!````
M`````````!$```!L`@`````````````2````;P$`````````````$@```.L`
M`````````````!$```#X`@`````````````2````/0$`````````````$@``
M`,H``````````````!(````?`P`````````````B````N0$`````````````
M$@```#L"`````````````!(```#J`0`````````````2````B`(`````````
M````$@```*8!`````````````!(```!Y`@`````````````2````L@$`````
M````````$@```$L!`````````````!(````!`P`````````````2````+0``
M````````````(````$T"`````````````!(```#$`0`````````````1````
M#@,`````````````$@```'@``````````````!(```"6`@`````````````2
M````4@,`````````````$@```.,!`````````````!(```"G````````````
M```2````9`$`````````````$@```',"`````````````!(```!:`@``````
M```````2````*@$`````````````$@````L"`````````````!(```"!`@``
M```````````2````:@``````````````$@```!X!`````````````!(```"_
M`@`````````````2````FP$`````````````$@```/@``````````````!(`
M``!$`P`````````````2````CP(`````````````$@```&4#````````````
M`"$```!]`0`````````````2````AP``````````````$@```#P`````````
M`````"````#<```````````````2````6P$`````````````$@```!4#````
M`````````!(```"J`@`````````````2````4```````````````(````%("
M`````````````!(```!F`P`````````````1````X`(`````````````$@``
M`/<!`````````````!(```#-`@`````````````2````'`(`````````````
M$@```&,"`````````````!(```#8`@`````````````2````+@,`````````
M````$@```-,#``#P7```=P```!(`#0"A`P``-%X````````2``X`^`,``#!,
M``!I#0``$@`-`%\#``#0$P``0`(``!(`#0"G`P``$$4```4````2``T`7@0`
M`"!%``#O`0``$@`-`%@$``"D$0```````!(`"@"+!```H%D``%`#```2``T`
MA@,``!#`````````$``8`-\#```01P``(@```!(`#0`L`@``3%X```0````1
M``\`D@,``%30````````$``8`%8$``"@0P``.P```!(`#0!K!```T$H``%H!
M```2``T`?00``!!*``!Y````$@`-``4$````P````````!``%P#L`P``0$<`
M`.@````2``T`?P,``!#`````````$``7`#@$```,P```!````!$`%P"7`P``
M$%X```(````2``T`*`0``+!=``!=````$@`-``L$```0%@```````!(`#0`'
M!````,`````````@`!<`0@0``$A>```$````$0`/`+@#``"02@``-````!(`
M#0`2!```0$0``,D````2``T`200``#!(``#9`0``$@`-``!L:6)P97)L+G-O
M+C4N,C(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R
M=%]?`%]*=E]296=I<W1E<D-L87-S97,`7TE435]R96=I<W1E<E1-0VQO;F54
M86)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K
M7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R
M;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!0
M3%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?
M9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S
M971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L
M7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?
M<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y
M7W=R87``;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!L<V5E:S8T`')E860`<'1H
M<F5A9%]G971S<&5C:69I8P!?7V5R<FYO7VQO8V%T:6]N`&-L;W-E`&QI8F,N
M<V\N-@!?24]?<W1D:6Y?=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T
M<FYC;7``7U]S=')D=7``8VQO<V5D:7(`=6YL:6YK`&UK9&ER`')E86QL;V,`
M;65M8VAR`&=E='!I9`!S=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P
M<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E
M;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P
M>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN
M=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I
M;@!?7V5N=FER;VX`7U]S=&%C:U]C:&M?9F%I;`!?961A=&$`7U]B<W-?<W1A
M<G0`7V5N9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE8P!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!P87)?8F%S96YA
M;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!P87)?
M8W5R<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?
M9G!?:'<`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S
M971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"
M3T]4`$=,24)#7S(N,@!'3$E"0U\R+C``1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS
M+C(`1TQ)0D-?,BXQ+C,`1TQ)0D-?,BXT``````(``@`#`````@`"``(``@`"
M``(```````(```````0``@````(```````(```````4````&``<``@````(`
M`@````@````"`````@````(``@`'```````"``(````#``(```````@`````
M``(``@`"```````````````)``@````"``(`"0`#``D``P`"``(`"``!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``(`TP$``!`````P````$FEI#0``!P"A!```$````!!I:0T```,`
MJP0````````!``8`(@(``!``````````$FEI#0``"0"A!```$````'09:0D`
M``@`M00``!````!R&6D)```&`,$$```0````<Q]I"0``!0#-!```$````!1I
M:0T```0`V00``!`````0:6D-```"`*L$````````U+T```@```#8O0``"```
M`+2_```(````!,````@````,P```"````-R^```&`0``X+X```8"``#DO@``
M!@,``.B^```&!```[+X```8&``#PO@``!@<``/2^```&"```^+X```8)``#\
MO@``!@H```"_```&"P``!+\```8,```(OP``!@T```R_```&#@``$+\```8/
M```4OP``!A```!B_```&$0``'+\```82```@OP``!A,``"2_```&%```*+\`
M``85```LOP``!A8``#"_```&%P``-+\```88```XOP``!AD``#R_```&&@``
M0+\```8;``!$OP``!AP``$B_```&'0``3+\```8>``!0OP``!A\``%2_```&
M(```6+\```8A``!<OP``!B(``&"_```&(P``9+\```8D``!HOP``!B4``&R_
M```&)@``<+\```8G``!TOP``!B@``'B_```&*0``?+\```8J``"`OP``!BL`
M`(2_```&+```B+\```8M``",OP``!BX``)"_```&+P``E+\```8P``"8OP``
M!C$``)R_```&,@``H+\```8S``"DOP``!C0``*B_```&-0``K+\```8V``"P
MOP``!C<``+B_```&.```O+\```8Z``#`OP``!CL``,2_```&/```R+\```8]
M``#,OP``!CX``-"_```&/P``U+\```9```#8OP``!D$``-R_```&0@``X+\`
M``9#``#DOP``!D0``.B_```&10``[+\```9&``#POP``!D<``/2_```&2```
M^+\```9)``#\OP``!DH``%.#[`CHHP0``('#(ZT``(N#D````(7`=`7H_@``
M`(/$"%O#````````````_[,$````_Z,(`````````/^C#````&:0_Z,0````
M9I#_HQ0```!FD/^C'````&:0_Z,D````9I#_HR@```!FD/^C+````&:0_Z,P
M````9I#_HS@```!FD/^C/````&:0_Z-`````9I#_HT0```!FD/^C2````&:0
M_Z-0````9I#_HU0```!FD/^C7````&:0_Z-@````9I#_HV0```!FD/^C:```
M`&:0_Z-L````9I#_HW````!FD/^C=````&:0_Z-X````9I#_HWP```!FD/^C
M@````&:0_Z.$````9I#_HX@```!FD/^CC````&:0_Z.0````9I#_HY0```!F
MD/^CG````&:0_Z.@````9I#_HZ0```!FD/^CJ````&:0_Z.L````9I#_H[``
M``!FD/^CM````&:0_Z.X````9I#_H[P```!FD/^CQ````&:0_Z/(````9I#_
MH\P```!FD/^CT````&:0_Z/4````9I#_H]@```!FD/^CW````&:0_Z/@````
M9I#_H^@```!FD/^C[````&:0_Z/X````9I#_H_P```!FD/^C``$``&:0_Z,$
M`0``9I#_HPP!``!FD/^C%`$``&:0_Z,8`0``9I#_HQP!``!FD/^C(`$``&:0
M_Z,D`0``9I#_HR@!``!FD/^C+`$``&:0``````````"-3"0$@^3P_W'\58GE
M5U9348G.Z&@"``"!P^BJ``"#["R+002)1=2+00B)1=!EH10```")1>0QP(U%
MT%"-1=104>C"_O__BX/`````@\0,4%#_L_````#H1$D``(N#6````(/$$(`X
M``^$)@$``(N[3````(/L#/\WZ$K___^`B`H#```"6O\WZ#O___^`B`H#```!
MBP:#Q!"#P`4]____/P^'60$``(/L#,'@`E#H%?[__XM]U(LV@\00B8-T$0``
MQX-X$0``!````(L7@_X!B1"-DUNA__^)4`2+DSP!``")4`B-DUZA__^)4`RZ
M`0```'X2C70F`(L,EXE,D`R#P@$Y\G7R@^P,QT2P#`````"#Q@-J`%"-@Q"%
M__]64/^S@!$``.A&_O__@\0@A<")Q@^$E@```(/L#/^S@!$``(U]X.@X_?__
MC8,?H/__B?KH^R<``(/$$(7`#X2%````@^P,_[.`$0``Z/+\___HY?W__X/$
M$(GPBWWD93,]%`````^%J0```(UE\%E;7E]=C6'\P^@/_?__A<")@X`1```/
MA(\```"#[`Q0Z*C\__^+NTP```!9_S?H"O[__X/$$,:`>04```#II_[__X/L
M#/^S@!$``.C%_?__@\00B<;I4O___XN#?!$``(7`="6#[`Q0Z"A'``"#Q!#I
M8/___U!0C8//G____[.8````4.@4_?__C8/4G___B?KH+R<``(7`B8-\$0``
M#X0Q____Z[[H&D@``(/L#&H!Z+C\__\Q[5Z)X8/D\%!44N@B````@<.PJ```
MC8-`G___4(V#X)[__U!15O^SY````.BG_/__](L<),-FD&:09I!FD&:0BQPD
MPV:09I!FD&:09I!FD.@7`0``@<)KJ```C8I``0``C8)#`0``*<B#^`9V%XN"
M&````(7`=`U5B>6#[!11_]"#Q!#)\\.)]HV\)P````#HUP```('"*Z@``%6-
MBD`!``"-@D`!``")Y5,IR,'X`H/L!(G#P>L?`=C1^'04BY((`0``A=)T"H/L
M"%!1_]*#Q!"+7?S)PXGVC;PG`````%6)Y5/H5____X'#UZ<``(/L!("[4`$`
M``!U)XN#:````(7`=!&#[`S_LS0!``#H3?O__X/$$.@U____QH-0`0```8M=
M_,G#B?:-O"<`````Z#<```"!PHNG``"-@@S___^+"(7)=0GI1/___XUT)@"+
MDO0```"%TG3M58GE@^P44/_2@\00R>DD____BQ0DPU57C6@X5E.![`P#``")
M1"1,C80D@````(E\)!1EBQ44````B90D_`(``#'2C90D``$``(GOB70D$(G%
MB50D")"+!XM7!#';QT7\`````(/'"(/%$`_(B=:)T8E%Z(G0P>88P>`(B=HE
M``#_``GPB<:)R`^LT!C!ZA@)QHG(B10D#ZS8""4`_P``"?")1?"+!"2)1?0Y
M;"0(=::-A"3@````C90DX`(``(G%B10DC78`BU4`BT4$@\4(,U70,T74,U6@
M,T6D,U60,T64QT44`````(G'B=&)T`^L^1\!T`G!B4T0.RPD=<B+1"1,,=*+
M>`B+<!"+:`R+"(M8!(E\)!B+>!2)-"2+<!B);"0<BV@DB7PD!(MX'(ET)`B)
MSHE,)!#!Y@6);"1<B5PD%(E\)`R+>"")]0^LV1N)?"18"<V+?"18`WPD>(GH
MBVPD7!-L)'R)^8'!F7F"6HGK@],``<B+3"08$=J+'"2)1"0@B50D)(M4)`B)
MW3'5B>\ASXGZBWPD"(MT)""+;"0<BTPD#(L<),=$)"0`````,?J+?"08QT0D
M-``````!UHET)"")="0HB?K!XAX/K.\"B=6+5"0("?T#E"2`````$XPDA```
M`(EL)#"+;"0PB=`%F7F"6HG*BTPD$(/2`#'=B40D.(GOB50D/(M$)"`AS\=$
M)#P`````B?J+/"2)QC'ZB<>+1"00B=&+5"0D`TPD.,'F!8ET)#B+="0X#ZS7
M&XM4)!2)RXG!"?X!\\'A'C'_#ZS0`HG-BU0D,(E<)%`)Q8G>B6PD.(ML)"#W
MU2'JBVPD*"-L)#C'1"0L`````,=$)$0`````B>B)U8M4)"0)Q8L$)`.$)(@`
M``")Z<=$)"0`````!9EY@EH!P8G8P>`%B40D*(G8BVPD*`^L^!N)1"1`"VPD
M0(M$)"`!Z8E,)"B)3"1@B<'!X1X/K-`"B<V+5"0X"<6+1"0PB6PD0(G=]]4A
MZHML)%`C;"1`">H#A"20````B=&+5"0L!9EY@EH!P8M$)"C!X`6)1"0@BT0D
M*(ML)"`/K-`;B40D,`ML)#`!Z8E,)%")3"0@B=D/K/X"P>$>B<T)]8EL)#"+
M;"0HBU0D0(MT)#C'1"0T`````,=$)#P`````]]4AZHML)&`C;"0PB>B)U8M4
M)"0)Q0.T))@```")Z8GP!9EY@EH!P8M$)"")QHG'P>8%B70D.(MT)#@/K-<;
MBU0D+,=$)"P`````"?Z)\(G.`<:+1"0H,?^)="1@B<'!X1X/K-`"B<V+5"0P
M"<6+1"1`B6PD.(ML)"#WU2'JBVPD4"-L)#@)Z@.$)*````")T069>8):`<&)
M\,'@!8E$)"B)\(ML)"@/K/@;B40D0`ML)$"+1"0@`>F)3"10B4PD*(G!BU0D
M),'A'L=$)"0`````B<W'1"1$`````,=$)#0`````#ZS0`HGR"<7WTB-4)#B)
M;"1`BVPD8"-L)$"+1"0P">H#A"2H````B=&+5"0L!9EY@EH!P8M$)"C!X`6)
M1"0@BT0D*(ML)"`/K-`;BU0D0(E$)#`+;"0P`>F)3"0@B4PD8(GQP>$>#ZS^
M`HG-"?6+="0XB6PD,(ML)"CWU2'JBVPD4"-L)#")Z(G5BU0D)`G%`[0DL```
M`(GIB?`%F7F"6@'!BT0D((G&B<?!Y@6)="0XBW0D.`^LUQL)_HGPB<X!QC'_
MB70D4(M$)"B+5"0LQT0D+`````#'1"0\`````,=$)$0`````B<'!X1X/K-`"
MB<V+5"0P"<6+1"1`B6PD.(ML)"#WU2'JBVPD8"-L)#@)Z@.$)+@```")T8M4
M)"0%F7F"6@'!B?#!X`6)1"0HB?"+;"0H#ZSX&XE$)$`+;"1`BT0D(`'IB4PD
M*(E,)&")P<'A'@^LT`*)S8GR"<7WTB-4)#B);"1`BVPD4"-L)$"+1"0P">H#
MA"3`````B=&+5"0L!9EY@EH!P8M$)"C!X`6)1"0@BT0D*`^LT!N)1"0PBVPD
M(`ML)#"+5"1`QT0D)`````#'1"0T`````,=$)#P``````>F)3"0@B4PD4(GQ
MP>$>#ZS^`HG-"?6+="0XB6PD,(ML)"CWU2'JBVPD8"-L)#")Z(G5BU0D)`G%
M`[0DR````(GIB?`%F7F"6@'!BT0D((G&B<?!Y@6)="0XBW0D.`^LUQN+5"0L
M"?Z)\(G.`<:+1"0H,?^)="1@B<'!X1X/K-`"B<V+5"0P"<6+1"1`B6PD.(ML
M)"#WU2'JBVPD4"-L)#@)Z@.$)-````")T069>8):`<&)\,'@!8E$)"B)\`^L
M^!N)1"1`BVPD*`ML)$"+1"0@BU0D),=$)"P`````QT0D1`````#'1"0D````
M`,=$)#0``````>F)3"0HB4PD4(G!P>$>#ZS0`HG-B?()Q??2(U0D.(EL)$"+
M;"1@(VPD0(M$)#`)Z@.$)-@```")T8M4)"P%F7F"6@'!BT0D*,'@!8E$)""+
M1"0HBVPD(`^LT!N+5"1`B40D,`ML)#`!Z8E,)&")3"0@B?'!X1X/K/X"B<T)
M]8MT)#B);"0PBVPD*/?5(>J+;"10(VPD,(GHB=4)Q0.T).````"+5"0DB>G'
M1"0\`````,=$)$0`````B?`%F7F"6@'!BT0D((G&B<?!Y@6)="0XBW0D.`^L
MUQN+5"0LQT0D+``````)_HGPB<X!QHM$)"@Q_XET)%")P<'A'@^LT`*)S8M4
M)#`)Q8M$)$");"0XBVPD(/?5(>J+;"1@(VPD.`GJ`X0DZ````(G1BU0D)`69
M>8):`<&)\,'@!8E$)"B)\(ML)"@/K/@;B40D0`ML)$"+1"0@`>F)3"1@B4PD
M*(G!P>$>#ZS0`HG-B?()Q??2(U0D.(EL)$"+;"10(VPD0(M$)##'1"0D````
M`,=$)#0`````QT0D/``````)Z@.$)/````")T8M4)"P%F7F"6@'!BT0D*,'@
M!8E$)""+1"0HBVPD(`^LT!N+5"1`B40D,`ML)#`!Z8E,)"")3"10B?'!X1X/
MK/X"B<T)]8MT)#B);"0PBVPD*/?5(>J+;"1@(VPD,(GHB=6+5"0D"<4#M"3X
M````B>F)\`69>8):`<&+1"0@B<:)Q\'F!8ET)#B+="0X#ZS7&XM4)"P)_HGP
MB<X!QHM$)"@Q_XET)&")P<'A'@^LT`*)S0G%B6PD.(ML)""+5"0PBT0D0,=$
M)"P`````]]4AZHML)%`C;"0X">H#A"0``0``B=&+5"0DQT0D)``````%F7F"
M6@'!B?#!X`6)1"0HB?"+;"0H#ZSX&XE$)$`+;"1`BT0D(`'IB4PD*(E,)%")
MP<'A'@^LT`*)S8GR"<7WTB-4)#B);"0@BVPD8"-L)""+1"0P">H#A"0(`0``
MB=&+5"0L!9EY@EH!P8M$)"C!X`6)1"0PBT0D*(ML)#`/K-`;B?*)1"1`"VPD
M0`'IP>(>#ZS^`HE,)&")3"0PB?#'1"0T`````(G6BU0D*(M<)%`)QHET)&B)
M="1`QT0D1`````#'1"0D`````/?2(U0D("'SBW0D.`G:`[0D$`$``(G1BU0D
M-(GP!9EY@EH!P8M$)#")RXG&P>8%B70D.(G&BT0D*`^LUAN+5"0LB?>+="0X
MB<$)_@'SP>$>,?\/K-`"B<V+3"0@BU0D-`G%`XPD&`$``(G>B6PD.(ML)&B)
M7"10B<@%H>O9;C-L)#@S;"1@B>D!P8G8P>`%B40D((G8BVPD(`^L^!N)1"0H
M"VPD*(M$)#`!Z8E,)&")3"0@B<'!X1X/K-`"B<N+5"1`BVPD4`G#`Y0D(`$`
M`,=$)"P`````B5PD0(G0BU0D)`6AZ]EN,UPD.#'=BUPD0(GI`<&+1"0@P>`%
MB40D*(M$)""+;"0H#ZS0&XGRB40D,`ML)#"+1"0X`>G!XAZ+;"1@#ZS^`HE,
M)"B)3"10B?&)UHM4)"P)SHN,)"@!``")="0X@<&AZ]EN`<@Q\S'=B>D!P8M$
M)"B)QL'F!8ET)#")QHM$)"`/K-8;BU0D)(GWBW0D,`G^`?$Q_XG.B4PD8(G!
MP>$>#ZS0`HG-BXPD,`$```G%BT0D0(EL)#"+;"0X@<&AZ]EN`<@S;"0PBU0D
M+#-L)%#'1"0D`````,=$)"P`````B>D!P8GPP>`%B40D((GPBVPD(`^L^!N)
M1"1`"VPD0(M$)"@!Z8E,)"")3"10B<'!X1X/K-`"B<N+C"0X`0``BU0D)`G#
MBT0D.(G=B5PD.(M<)#"!P:'KV6X!R#'KBVPD8#'=BUPD.(GI`<&+1"0@P>`%
MB40D*(M$)""+;"0H#ZS0&XE$)$`+;"1``>F+;"10B4PD*(E,)&")\0^L_@+!
MX1Z)\(G.BXPD0`$```G&BT0D,(ET)$"!P:'KV6X!R#'S,=V)Z0'!BT0D*(M4
M)"R)RXG&P>8%B70D,(G&BT0D(`^LUAN+5"0DQT0D)`````")]XMT)#")P0G^
M`?/!X1XQ_P^LT`*)S8N,)$@!``"+5"0L"<6+1"0XB5PD4(EL)#"+;"1`B=Z!
MP:'KV6X!R#-L)#`S;"1@B>D!P8G8P>`%B40D((G8BVPD(`^L^!N)1"0X"VPD
M.(M$)"@!Z8E,)"")3"1@B<'!X1X/K-`"B<N+C"10`0``BU0D)`G#BT0D0(G=
MB5PD.(M<)#"!P:'KV6X!R#'KBVPD4#'=B>D!P8M$)"#!X`6)1"0HBT0D((ML
M)"@/K-`;B40D0`ML)$"+7"0XQT0D+`````"+5"0L`>F+;"1@B4PD4(E,)"B)
M\0^L_@+!X1Z)\(G.BXPD6`$```G&BT0D,(ET)$"!P:'KV6X!R#'S,=V)Z0'!
MBT0D*(G+B<;!Y@6)="0PB<:+1"0@#ZS6&XM4)"3'1"0D`````(GWBW0D,(G!
M"?X!\\'A'C'_#ZS0`HG-BXPD8`$``(M4)"P)Q8M$)#B)WHEL)#"+;"1`@<&A
MZ]ENB5PD8`'(,VPD,#-L)%")Z0'!B=C!X`6)1"0@B=B+;"0@#ZSX&XE$)#@+
M;"0XBT0D*`'IB4PD4(E,)"")P<'A'@^LT`*)RXN4)&@!```)PXM$)$#'1"0L
M`````(E<)#B)W8M<)#"!PJ'KV6X!T(M4)"0QZXML)&`QW8M<)#B)Z0'!BT0D
M(,'@!8E$)"B+1"0@BVPD*`^LT!N+5"0LB40D0`ML)$`!Z8ML)%")3"1@B4PD
M*(GQ#ZS^`L'A'HGPB<Z+C"1P`0``"<:+1"0PB70D0('!H>O9;@'(,?,QW8GI
M`<&+1"0HB<N)QL'F!8ET)#")QHM$)"`/K-8;BU0D)(GWBW0D,(G!"?X!\\'A
M'C'_#ZS0`HG-BXPD>`$``(E<)%`)Q8M$)#B)WHEL)#"+;"1`@<&AZ]EN`<@S
M;"0P,VPD8(GI`<&)V,'@!8E$)"")V(ML)"`/K/@;BU0D+,=$)"0`````B40D
M.`ML)#B+1"0HQT0D+``````!Z8E,)"")3"1@B<'!X1X/K-`"B<N+E"2``0``
M"<.+1"1`B=V)7"0XBUPD,('"H>O9;@'0BU0D)#'KBVPD4#'=B>D!P8M$)"#!
MX`6)1"0HBT0D((ML)"@/K-`;BU0D+(E$)$`+;"1``>F+;"0XB4PD*(E,)%")
M\0^L_@+!X1Z)\(G.BXPDB`$```G&BT0D,(ET)$"!P:'KV6X!R#'UB>Z+;"1@
M,?6)Z0'!BT0D*(G+B<;!Y@6)="0PB<8/K-8;B?>+="0P"?X!\S'_B5PD8(M$
M)"")WHM4)"3'1"0D`````(G!P>$>#ZS0`HG-BXPDD`$``(M4)"P)Q8M$)#C'
M1"0L`````(EL)#"+;"1`@<&AZ]EN`<@S;"0P,VPD4(GI`<&)V,'@!8E$)"")
MV(ML)"`/K/@;B40D.`ML)#B+1"0H`>F)3"0@B4PD4(G!P>$>#ZS0`HG+BY0D
MF`$```G#BT0D0(G=B5PD.(M<)#"!PJ'KV6X!T(M4)"0QZXML)&`QW8GI`<&+
M1"0@P>`%B40D*(M$)""+;"0H#ZS0&XE$)$`+;"1``>F)3"1`B4PD*(GQ#ZS^
M`L'A'HGPB<Z+C"2@`0``"<:+7"0XBT0D,(ML)%")="0P@<&AZ]ENBU0D+`'(
M,?,QW8GI`<&+1"0HB<N)QL'F!8ET)%")QHM$)"`/K-8;BU0D)(GWBW0D4(G!
M"?X!\\'A'C'M#ZS0`HG?B5PD8(N<)*P!```)P8M$)#B)SHN,)*@!``")="10
M@<&AZ]EN@],`,=(!R!':BTPD,(E$)"")5"0DBU0D0(GXQT0D)``````Q\3'*
MB=$#3"0@P>`%B40D((GXBW0D(`^LZ!N+5"0LB40D.`MT)#B+1"0H`?&)3"1`
MB4PD((G!P>$>#ZS0`HN4)+`!``")SHN,)+0!```)QHM$)#")="0X@<*AZ]EN
M@]$`B<N)T3'2`<B+3"10$=J)1"0HBT0D((E4)"R+5"1@,?&+7"0XQT0D+```
M```QRHG1`TPD*,'@!8E$)"B+5"0DBT0D((MT)"@/K-`;B=J)1"0P"W0D,(M$
M)$`!\8G^B4PD*(E,)&")^0^L[@+!X1XQ_XG-"?6)WHN<)+P!```)[B'JB6PD
M0"'PB<&+1"10"=&)SHN,)+@!``"!P=R\&X^#TP`QT@'($=H!QHM$)"@1UXM4
M)"R)="0PB7PD-(G&#ZS0&\'F!8G!"?&)R(M,)#`!P8E,)&B)3"0PQT0D-```
M``"+="0@BWPD)(M$)&#'1"0D`````(GQP>$>#ZS^`HG+"?.+="1`B=^)^HE\
M)%"+?"0L"?,A\L=$)"P`````(=B)P8M$)#@)T8N4),`!``")SHGS@<+<O!N/
M`="+5"0T`<.+1"0PB<8/K-`;P>8%B40D((ML)""+1"1H"?6+="0H`>N)7"1@
MB5PD((GQ#ZS^`HM\)%#!X1Z)RPGSB?J)^8E<)#@)VB'9(="+5"0DB<6+1"1`
M"<V+C"3(`0``@<'<O!N/`<B)Z0'!BT0D((G&P>8%B70D*(G&BT0D8`^LUAN+
M5"0XB?>+="0HB=,)_HM\)#0!\8MT)#")3"1HB4PD*(GQP>$>#ZS^`HG-"?4)
MZXEL)$"+C"30`0``(=B)TXM\)"0AZ\=$)#0`````QT0D)`````")VHG#BT0D
M4`G3@<'<O!N/BU0D+`'(`<.+1"0HB<8/K-`;P>8%BU0D0(E$)#"+;"0PBT0D
M:`GUBW0D(`'KB5PD8(E<)#")\<'A'@^L_@*)RPGSB=\)TR'8B?F)?"10(=&)
MQ8M$)#@)S8N,)-@!``"+5"0TBWPD+('!W+P;CP'(B>D!P8M$)#")Q@^LT!O!
MY@6)1"0@BVPD((M$)&`)]8MT)"@!Z8E,)"")3"1HB?$/K/X"BWPD4,'A'HG+
MBXPDX`$```GSB?J)7"0X"=HAT(GZB<6+1"1`(=H)U8'!W+P;CXM4)"2)[@'(
M`<:+1"0@B?&)QL'F!8ET)"B)QHM$)&@/K-8;BU0D.,=$)"P`````B?>+="0H
MB=,)_HM\)#3'1"0T``````'QBW0D,(E,)&")3"0HB?'!X1X/K/X"B<V+?"0D
MQT0D)``````)]0GKB6PD0"'8B=.+5"0L(>N)P8M$)%`)V8G.BXPDZ`$``(GS
M@<'<O!N/`<@!PXM$)"B)Q@^LT!O!Y@6+5"1`B40D,(ML)#"+1"1@"?6+="0@
M`>N)7"0PB5PD:(GQP>$>#ZS^`HG+"?.)WPG3(=B)^8E\)%`AT8G%BT0D.`G-
MBXPD\`$``(M4)#2!P=R\&X\!R(GI`<&+1"0PB<8/K-`;P>8%B40D((ML)"`)
M]0'IB4PD8(E,)""+="0HBWPD+(M$)&C'1"0L`````(GQ#ZS^`HM\)%#!X1Z)
MRXN,)/@!```)\XGZB5PD.`G:(=")^HG%BT0D0"':"=6!P=R\&X^+5"0DB>X!
MR`'&BT0D((GQB<;!Y@6)="0HB<:+1"1@#ZS6&XM4)#B)]XMT)"B)TPG^BWPD
M-,=$)#0``````?&+="0PB4PD:(E,)"B)\<'A'@^L_@*)S8M\)"0)]0GKB6PD
M0"'8B=.+5"0L(>N)P8M$)%`)V8G.BXPD``(``(GS@<'<O!N/`<@!PXM$)"B)
MQ@^LT!O!Y@6+5"1`B40D,(ML)#"+1"1H"?6+="0@`>N)7"1@B5PD,(GQP>$>
M#ZS^`HG+"?.)WPG3(=B)^8E\)%`AT8G%BT0D.`G-BXPD"`(``(M4)#2+?"0L
MQT0D)`````#'1"0L`````('!W+P;CP'(B>D!P8M$)#")Q@^LT!O!Y@6)1"0@
MBVPD((M$)&`)]8MT)"@!Z8E,)&B)3"0@B?$/K/X"BWPD4,'A'HG+BXPD$`(`
M``GSB?J)7"0X"=HAT(GZB<6+1"1`(=H)U8'!W+P;CXM4)"2)[@'(`<:+1"0@
MB?&)QL'F!8ET)"B)QHM$)&@/K-8;BU0D.(GWBW0D*(G3"?Z+?"0T`?&+="0P
MB4PD*(E,)&")\<'A'@^L_@*)S0GU">N);"1`(=B)TXM4)"PAZXG!BT0D4`G9
MB<Z+C"08`@``B?.!P=R\&X\!R`'#BT0D*(G&#ZS0&\'F!8E$)#"+;"0PBWPD
M)(M4)$"+1"1@QT0D-``````)]8MT)"#'1"0D``````'KB5PD:(E<)#")\<'A
M'@^L_@*)RPGSB=\)TR'8B?F)?"10(=&)Q8M$)#@)S8N,)"`"``"+5"0TBWPD
M+,=$)"P`````@<'<O!N/`<B)Z0'!BT0D,(G&#ZS0&\'F!8E$)""+;"0@BT0D
M:`GUBW0D*`'IB4PD((E,)&")\0^L_@*+?"10P>$>B<N+C"0H`@``"?.)^HE<
M)#@)VB'0B?J)Q8M$)$`AV@G5@<'<O!N/BU0D)(GN`<@!QHM$)"")\8G&P>8%
MB70D*(G&#ZS6&XGWBW0D*`G^`?&)3"1HB4PD*(MT)#"+?"0TBU0D.(M$)&#'
M1"0T`````(GQP>$>B=,/K/X"B<V+?"0DQT0D)``````)]0GKB6PD0"'8B=.+
M5"0L(>N)P8M$)%`)V8G.BXPD,`(``(GS@<'<O!N/`<@!PXM$)"B)Q@^LT!O!
MY@6+5"1`B40D,(ML)#"+1"1H"?6+="0@`>N)7"1@B5PD,(GQP>$>#ZS^`HG+
M"?.)WPG3(=B)^8E\)%`AT8G%BT0D.`G-BXPD.`(``(M4)#2+?"0L@<'<O!N/
M`<B)Z0'!BT0D,(G&#ZS0&\'F!8E$)""+;"0@BT0D8`GUBW0D*`'IB4PD:(E,
M)"")\0^L_@*+?"10P>$>B<L)\XGZB5PD.(N,)$`"```)VL=$)"P`````(=")
M^HG%BT0D0"':"=6!P=R\&X^+5"0DB>X!R`'&BT0D((GQB<;!Y@6)="0HB<:+
M1"1H#ZS6&XM4)#B)]XMT)"B)TPG^BWPD-,=$)#0``````?&+="0PB4PD8(E,
M)"B)\<'A'@^L_@*)S3'_"?4)ZXEL)$`AV(G3(>N)P8M$)%`)V8N<)$P"``")
MSHN,)$@"``"!P=R\&X^#TP`QT@'($=J)\XG^`<.+1"0HBWPD)!'6BU0D+(G9
MB?.)Q@^LT!O!Y@4QTHE$)#"+;"0PBT0D8`GUB=Z)RP'K$=:)7"1HB5PD,(ET
M)&R+="0@B?'!X1X/K/X"B<N+?"1`"?.)WHG9B5PD4`G^(?DA\(G%BT0D.`G-
MBXPD4`(``('!W+P;CP'(B>D!P8M$)#"+5"0TBWPD+,=$)"0`````B<8/K-`;
MP>8%BY0D6`(``(E$)""+;"0@"?6+="0H`>F+;"10B4PD8(E,)"")\0^L_@+!
MX1Z)\(G."<:+1"1`@<+6P6+*B70D.`'0,?6+5"0DB>Z+;"1H,?6)Z0'!BT0D
M((G+B<;!Y@6)="0HB<:+1"0P#ZS6&XM4)#2)]XMT)"B)P0G^`?/!X1XQ_P^L
MT`*)S8N,)&`"``")7"1`"<6+1"10B=Z);"0PBVPD.('!UL%BR@'(,VPD,#-L
M)&")Z0'!B=C!X`6)1"0HB=B+;"0H#ZSX&XE$)%`+;"10`>F)3"10B4PD*(M$
M)""+5"0DQT0D+`````#'1"0D`````(G!P>$>#ZS0`HG+BXPD:`(``(M4)"P)
MPXM$)#B)W8E<)#B+7"0P@<'6P6+*`<@QZXML)$`QW8M<)#B)Z0'!BT0D*,'@
M!8E$)""+1"0HBVPD(`^LT!N+5"0DB40D0`ML)$`!Z8ML)%")3"0@B4PD8(GQ
M#ZS^`L'A'HGPB<Z+C"1P`@``"<:+1"0PB70D0('!UL%BR@'(,?,QW8GI`<&+
M1"0@B<N)QL'F!8ET)#")QHM$)"@/K-8;BU0D+(GWBW0D,(G!"?X!\\'A'C'_
M#ZS0`HG-BXPD>`(``(E<)%`)Q8G>B6PD,(M$)#B!P=;!8LJ+;"1`BU0D),=$
M)"P`````QT0D)``````!R#-L)#`S;"1@B>D!P8G8P>`%B40D*(G8BVPD*`^L
M^!N)1"0X"VPD.(M$)"`!Z8E,)"B)3"1@B<'!X1X/K-`"B<N+E"2``@``"<.+
M1"1`B=V)7"0XBUPD,('"UL%BR@'0BU0D+#'KBVPD4#'=B>D!P8M$)"C!X`6)
M1"0@BT0D*(ML)"`/K-`;B40D0`ML)$`!Z8ML)#B)3"1`B4PD((GQ#ZS^`L'A
M'HGPB<Z+C"2(`@``"<:+1"0PB70D,('!UL%BR@'(,?6)[HML)&"+5"0D,?6)
MZ0'!BT0D((G+B<;!Y@6)="10B<:+1"0H#ZS6&XM4)"S'1"0L`````(GWBW0D
M4(G!"?X!\\'A'C'_#ZS0`HG-BXPDD`(``(G>"<6)7"10BT0D.(M<)#");"0X
M@<'6P6+*BU0D)`'(,>N+;"1`,=V)Z0'!B?#!X`6)1"0HB?"+;"0H#ZSX&XE$
M)$`+;"1`BT0D(`'IB4PD*(E,)&")P<'A'@^LT`*)S8N4))@"```)Q8M$)#")
M;"1`@<+6P6+*`=`S;"0XBU0D+#-L)%")Z0'!BT0D*,'@!8E$)""+1"0H#ZS0
M&XE$)#"+;"0@"VPD,(M<)$#'1"0D`````(M4)"0!Z8ML)&")3"10B4PD((GQ
M#ZS^`L'A'HGPB<Z+C"2@`@``"<:+1"0XB70D.('!UL%BR@'(,?,QW8GI`<&+
M1"0@B<N)QL'F!8ET)#")QHM$)"@/K-8;BU0D+,=$)"P`````B?>+="0PB<$)
M_@'SP>$>,?\/K-`"B<V+C"2H`@``BU0D)`G%BT0D0(G>B6PD,(ML)#B!P=;!
M8LJ)7"1@`<@S;"0P,VPD4(GI`<&)V,'@!8E$)"B)V(ML)"@/K/@;B40D0`ML
M)$"+1"0@`>F)3"10B4PD*(G!P>$>#ZS0`HG+BY0DL`(``,=$)"0`````"<.+
M1"0XB=V)7"0XBUPD,('"UL%BR@'0BU0D+#'KBVPD8#'=B>D!P8M$)"C!X`6)
M1"0@BT0D*(ML)"`/K-`;BU0D)(E$)$`+;"1``>F+;"0XB4PD((E,)&")\0^L
M_@+!X1Z)\(G.BXPDN`(```G&BT0D,(ET)$"!P=;!8LH!R#'UB>Z+;"10,?6)
MZ0'!BT0D((G+B<;!Y@6)="0PB<:+1"0H#ZS6&XM4)"R)]XMT)#")P0G^`?/!
MX1XQ_P^LT`*)S8N,),`"``")7"10"<6+1"0XB=Z);"0PBVPD0('!UL%BR@'(
M,VPD,#-L)&"+5"0DQT0D+`````#'1"0D`````(GI`<&)V,'@!8E$)"B)V(ML
M)"@/K/@;B40D.`ML)#B+1"0@`>F)3"0HB4PD8(G!P>$>#ZS0`HG+BY0DR`(`
M``G#BT0D0(G=B5PD.(M<)#"!PM;!8LH!T(M4)"PQZXML)%`QW8N<)-0"``")
MZ0'!BT0D*,'@!8E$)""+1"0HBVPD(`^LT!N)1"1`"VPD0`'IBVPD.(E,)"")
M3"10B?$/K/X"P>$>B?")SHN,)-`"```)QHM$)#")="1`@<'6P6+*@],`,=(!
MR!':,?4QVXGNBVPD8#'UB>D!P8M$)"`1TXM4)"2)QL'F!8G7B70D,(G&#Z3'
M!0^LUAN)?"0T,=*)]XMT)#`)_HGPB=Z)RP'#BT0D*!'6BU0D+(G9B4PD8(ET
M)&2)SHG!,?_'1"0L``````^LT`+!X1Z+5"0DB<V+C"38`@``"<6+1"0XB6PD
M,(ML)$"!P=;!8LH!R#-L)#`S;"10B>D!P8GPP>`%B40D*(GPBVPD*`^L^!N)
M1"0X"VPD.(M$)"`!Z8E,)"B)3"10B<'!X1X/K-`"B<N+E"3@`@``"<.+1"1`
MB=V)7"0XBUPD,('"UL%BR@'0BU0D+#'KBVPD8#'=B>D!P8M$)"C!X`6)1"0@
MBT0D*`^LT!N)1"1`BVPD(`ML)$#'1"0D`````(M4)"0!Z8ML)#B)3"0@B4PD
M0(GQ#ZS^`L'A'HG7B?")SHN,).@"```)QHM$)#")="0P@<'6P6+*`<@Q]8GN
MBVPD4#'UB>D!P8M$)"")QL'F!8ET)%")Q@^DQP4/K-8;B7PD5(M4)"R)]XMT
M)%`)_HGP`<@Q_XG&BT0D*(G!P>$>#ZS0`HG-BU0D((M,)"0)Q8M$)#B);"10
M#Z31'L'B'HE4)"B)3"0LBU0D((M,)"0/K,H"P>D"B4PD)(N,)/`"``")5"0@
MB?J!P=;!8LH!R(M,)#`QZ8ML)$`QS8GI`<&)\,'@!8E$)#B)\`^D\@4/K/@;
MB50D/(GZB40D0(ML)#C!ZAL+;"1`B50D1(GHBVPD*`'(B<$#3"00BT0D3(G#
MQT`$`````(D(BT0D&,=##`````#'0Q0`````QT,<`````,=#)``````!\`ML
M)"")0PB)Z`,$)(E#$(M$)%`#1"0(B4,8BT0D,`-$)%B)0R"+A"3\`@``93,%
M%````'4+@<0,`P``6UY?7</H"R$``(UT)@"-O"<`````55=64^@GV?__@<.G
M@0``@^P<A<!T;XN+$`$``(L)A<F)3"0(=%\/M@B$R71C@/D]=%Z)QH/&`0^V
M#H3)=`6`^3UU\2G&BTPD"(LIA>UT-HE4)`R)1"0$B<^-M"8`````@^P$5O]T
M)`Q5Z/K5__^#Q!"%P'4'@'PU`#UT'(/'!(LOA>UUVX/$'#'`6UY?7<.0,?;K
ML8UT)@")^BM4)`B+1"0,P?H"B1"#Q!R-1#4!6UY?7<.-M@````"-O"<`````
M5U:)QE/HDMG__X'"YH```(/L$(NZ$`$``(U<)`AEH10```")1"0,,<")VHGP
MZ`[___^%P'0[C78`C;PG`````(M4)`B+!XT$D(M0!(72B1!TUXVV`````(/`
M!(M0!(72B1!U](G:B?#HT_[__X7`=<^+1"0,93,%%````'4'@\006UY?P^BV
M'P``C;8`````55>)Q593B=;HT]?__X'#4X```(/L.&6A%````(E$)"@QP#'`
M@#H]#Y3``<96Z#[4__^#Q!")!"2)Z(U4)!CH;?[__X7`#X0-`0``@^P,B<=0
MZ!K4__^#Q!`Y!"0/AMX```"+1"08C0R%`````(N#$`$``(E$)`0/MD4`A,`/
MA)0!```\/0^$C`$``(GHZP:0@/H]=`J#P`$/MA"$TG7Q*>B+5"0$@^P,BSH!
MSXM,)`R-1`@"4.A^T___@\00A<")!P^$8P$``(M4)`2-30&+`HM4)!B+%)`/
MMD4`/#V(`G0CA,!U#^L=B?:-O"<`````/#UT$(/!`0^V0?^#P@&$P(@"=>S&
M`CTQP(VT)@`````/M@P&B$P"`8/``83)=?$QP(M<)!QE,QT4````#X4"`0``
M@\0L6UY?7<.-M@````"#Q@$/MD;_@\<!A,"(1_]U[^O,D(UT)@"+@Q`!``"+
M$(E$)`2+.H7_#X2P````,<#K"(VV`````(GXC7@!BPRZA<EU](T$A0P```"+
MBW`1``"%R70S@^P(4%+HD=+__XM,)!2#Q!"%P(D!='Z-#+T`````QT2X!```
M``")?"08Z;/^__^-="8`B50D"(/L#,>#<!$```$```!0Z%G2__^#Q!"%P'1$
MC0R]`````(/L!%&+5"00B4PD%%*)1"044.B,T?__BTPD%(M$)!B#Q!")`8M,
M)`SKG#'`Z8/^__^X"````#'_Z6'___^X_____^GM_O__Z'<=``"-M"8`````
M55=64XG&Z)75__^!PQ5^``"![(P```!EH10```")1"1\,<"%]G0%@#X`=22+
M1"1\93,%%`````^%-`$``('$C````%M>7UW#D(VT)@````"#[`Q6Z*_2__^#
MQ!"%P(G'=,J-@X"?__^)1"0(C40D'(E$)`R-="8`@^P,5^A'TO__@\00A<")
MQ0^$N@```(!]$RX/A(@```"#[`Q6Z(_1__^-51.)1"04B10DB50D$.A\T?__
MBTPD%(U$`0*)!"3H--'__XG%6%J+5"0(4E;_="08:O]J`57H--+__X/$'/]T
M)!!5:@/H]='__X/$$(/X_W00BT0D+"4`\```/0!```!T98/L#%7HC-#__X/$
M$(/L#%7H0-#__X/$$.E8____#[9%%(3`#X1,____/"X/A63___^`?14`#X0Z
M____Z57___^0C70F`(/L#%?HK]'__XDT).@7T/__@\00Z<O^__^-M"8`````
MB>CHD?[__^N>Z/H;``"-=@"-O"<`````5U:)QU/H%M3__X'#EGP``(/L#(NS
M3````/\VZ$C1__^#Q`P%.`$``%!7:@/H/]'__X/$$(7`=`A;,<!>7\-FD(/L
M#/\VZ![1__^+@$@!``"#Q!`E`/```#T`0```=!^#[`S_-NC_T/__BX!(`0``
M@\00)0#P```]`*```'6Z@^P(:@)7Z)?0__^#Q!"%P`^4P%L/ML!>7\.0C;0F
M`````%57B<=64^AUT___@</U>P``@>PP$```9:$4````B80D(!```#'`B50D
M$&C_#P``C8.&G___C70D)%90Z$C/__^#Q!"%P'YAC6C_@'PL'`!T3XG%@^P$
M56HO5NCQS___@\00A<!T0HN#3````(/L#/\PZ%+0__]55E=0Z!G0__^#Q""+
MA"0<$```93,%%````'4Y@<0L$```6UY?7<.-=@"%[76OC70F`(N#3````(/L
M#/\PZ!#0__^#Q`S_="005U#HRL[__X/$$.NWZ(`:``!3Z*K2__^!PRI[``"#
M[!2+@TP```#_,.C<S___C9.(H?__4HV3E9____^S-````%)0Z"K/__^#Q"A;
MPY"-="8`5E/H:=+__X'#Z7H``(/L$(NS3````/\VZ)O/__^)!"3HF____UC_
M-NB+S___6HV35:'__UEJ`%)2C9/0FO__4HV3L9___U)0Z!O/__^#Q"1;7L.-
MM@````"-O"<`````55=64^@'TO__@<.'>@``@>P<(```9:$4````B80D#"``
M`#'`Z"?.__^-DY&?__^#[`A24(V#QI___U!H`1```&H!C70D)E;H-,___X/$
M((7`>&V#[`1H`!```(V\)!,0``!75NBOS?__@\00A<")Q7A.C4`!@^P,4.CJ
MS?__@\00A<")QG0Y@^P$55=0Z#[-___&!"X`@\00B?"+C"0,(```93,-%```
M`'49@<0<(```6UY?7<.-=@"-O"<`````,<#KU^@7&0``C;0F`````.DK____
MC70F`(V\)P````!55U93Z"?1__^!PZ=Y``"![#P0``!EH10```")A"0L$```
M,<"+M"10$```C50D*(V#U)___XN\)%00``#HO_?__X/L"(G%:B]6Z&+-__^#
MQ!"%P'0NC8/=G___B?+H[OC__XGPBY0D+!```&4S%10````/A7(!``"!Q#P0
M``!;7E]=PX/L#%;H-,W__UI9B40D((V#ZI___XE$)"105^B5S?__@\00A<")
MQW2IC9/2G___B70D%(MT)!R)5"00BY-,````B50D#)"-M"8`````@#\`#T1\
M)!"%[705@^P(5U7HXLO__X/$$(7`#X2H````@^P,5^C&S/__@\00@'P'_R]U
M$HUT)@"#Z`&`?`?_+\8$!P!T\HM,)!B-1`@!/?\/```/CX@```"-@^R?__^#
M[`3_="084(V#$*'__U=0:``0``!J`8U\)$A7Z%#-__^#Q!2+1"08_S#H&LW_
M_X/$#`4X`0``4%=J`^@!S?__@\00A<!U(X/L#(M$)!C_,.CTS/__BX!(`0``
M@\00)0#P```]`(```'0A@^P(5FH`Z)3,__^#Q!"%P(G'#X4?____BW0D%.F;
M_O__@^P(:@%7Z&O,__^#Q!"%P'7-C8/=G___B?KH=_?__X/L#%?H#LS__X/$
M$.EZ_O__Z!$7``"0BT0D!`^V"(3)=!6-4`%FD(#Y+P^V"@]$PH/"`83)=?#S
MPXVT)@````"-O"<`````5E/H"<___X'#B7<``(/L%(MT)""%]G0X#[86A-)T
M,8A4)`^#[`Q6Z'3+__^-1`;_@\00#[94)`\YQG(+ZSYFD(/H`3G&=#F`."]T
M].LG9I"#[`QJ`N@.R___@\00A<!T?[HN````9HD0@\046U[#D(`X+W0P@^@!
M.<9R]#G&=26`^B]TRXV#[)___X/L#%#H/,O__X/$$.O0C;0F`````(`X+W4'
M@^@!.<9R]"GPC5`"@?H`$```=R>#P`%H`!```%!6C;-P`0``5N@IR___@\00
MB?"#Q!1;7L.-M@````"#Q!0QP%M>PY"-M"8`````5U93Z!C.__^!PYAV``"#
M[#!EH10```")1"0L,<"+@V2A__^-="0$B40D"HN#:*'__XE$)`Z+@VRA__^)
M1"02BX-PH?__B40D%HN#=*'__XE$)!J+@WBA__^)1"0>BX-\H?__B40D(HN#
M@*'__XE$)"8/MX.$H?__9HE$)"J-@^Z?___H*/7__XV#]Y___^@=]?__C8/_
MG___Z!+U__^-@PB@___H!_7__XV##Z#__^C\]/__C8,?H/__Z/'T__^-@]2?
M___HYO3__XV#*Z#__^C;]/__C8,UH/__Z-#T__^-@S^@___HQ?3__XV#W9__
M_^BZ]/__C8-)H/__Z*_T__^-@U*@___HI/3__XV#7:#__XGRZ-?S__^%P'0-
MB<*-@S6@___H%O7__XV#;J#__XGRZ+GS__^%P'0-B<*-@X"@___H^/3__XV#
MBZ#__XGRZ)OS__^%P'0WB<*-@]2?___HVO3__XV3MZ#__XV##Z#__^C)]/__
MBT0D+&4S!10```!U4(/$,%M>7\.0C70F`(V#FZ#__XGRZ%/S__^%P'0/B<*-
M@RN@___HDO3__^NVC70D&XV[K*#__[D*````\Z9UHXU4)"6-@RN@___H;O3_
M_^N2Z!<4``"-M"8`````4^@ZS/__@<.Z=```@^P89:$4````B40D##'`BX,X
M`0``@_C_=!J+3"0,93,-%````'5!@\086\.0C;0F`````(U4)`B-@RN@___H
MP?+__X7`=!T/MA"`^C`/E<"$T@^5P@^VTB'0B8,X`0``Z[AFD#'`Z_+HEQ,`
M`(VT)@````!3Z+K+__^!PSIT``"#[`CHG,?__X/L#%#H2\?__X/$$(7`=`R+
M`(/$"%O#D(UT)@`QP.ORC;8`````C;\`````55=64^AWR___@</W<P``@^Q<
MBT0D<(V[PZ#__XVSN:#__\=$)$@`````C6PD,(E\)#")="0TB40D"&6A%```
M`(E$)$PQP(V#QJ#__XE$)#B-@[R@__^)1"0\C8/!H/__B40D0(V#TZ#__XE$
M)$2-1"0LB40D#(V#ZI___XE$)!2-@Q"A__^)1"08ZRB-="8`@^P(_W0D$%")
M1"0@Z&_&__^#Q!"%P'1(@\4$A?9T*XGWBW4$BU0D#(GXZ)'Q__^%P'0%@#@`
M=<B+5"0(B?B#Q03HRO+__X7V==6+1"1,93,%%````'5N@\1<6UY?7<.0@^P,
M_W0D%.@4Q___BTPD((E$)"R)#"2)3"0@Z`#'__^+5"0LC40"`HD$).BXQO__
M@\0,BTPD%%'_="0<_W0D%/]T)"AJ_VH!4(E$)##HKL?__X/$((M4)!")^.A0
M\O__Z5/____H]A$``(VV`````%575E/H+A$``('!EW(``('L/($``(N$)%"!
M``"-;"0\C9G>H/__B4PD",=$)$@`````B>K'1"1L`````(E<)$R)1"00QT0D
M5`````!EH10```")A"0L@0``,<"-@>J@__^)1"1`C8'2G___B40D1(V!@*#_
M_XE$)!B)1"18C8%YH/__B40D7(V![Z#__XE$)&"-@9:@__^)1"1DC8'WH/__
MB40D:(V!^Z#__XE$)%"-@=2?___H-O#__X7`=`F`.``/A<D$``#HE/W__X7`
MB<8/A-\$``"#[`Q6BUPD&.C-Q?__C40``8/$$(/L#%"+7"08Z('%__^)1"0<
M@\00@#X`B<>+1"0(C8`$H?__=#F);"0<B?V)QXGVC;PG``````^V!H/L#(/&
M`5!7:O]J`56+7"0H@\4"Z%3&__^#Q""`/@!UW(ML)!R-7"18BT0D&.L/C;8`
M````@\,$BP.%P'0WB>KHB.___X7`B<9TZH`X`'3EZ(CT__^%P'3<@^P,5HM<
M)!CH5\7__X/$$(7`B<=U6(VV`````(M<)$"%VW1(@#L`O@$```!U%NL\C70F
M`(M<M$"%VW0P@\8!@#L`="B)V.@Y]/__A<!TY8/L#%.+7"08Z`C%__^#Q!"%
MP'31B<?K!Y"-="8`,?^#[`Q7BUPD&.BYQ/__@\00BTPD#(L9@\$$C9/__O[^
M]],AVH'B@("`@'3IB=/!ZQ#WPH"````/1-.-60(/1,N)TP#3@]D#*TPD#(/L
M#(VT`00$``!6BUPD&.@PQ/___W0D'(M4)!R)P8V"":'__XG34(V"[)___XE$
M)#!0C8(.H?__5U!J_VH!B4PD.%'H%,7__X/$*&C``0``_W0D&.A+Q/__@\00
M@_C_#X2/````@^P,BT0D%(NX3````(G#_S>)1"08Z+7$__^#Q`P%.`$``%#_
M="04:@.+7"08Z*7$__^#Q!"%P`^$F@```(/L#/]T)!B+1"0@_S"+7"0<C8/0
MH?__4(N#(````&H!_S#H4\3__X/$(#'`BY0D+($``&4S%10````/A4X*``"!
MQ#R!``!;7E]=PXVT)@````#HN\/__XL`@_@1#X1A____@^P(4/]T)!B+1"0@
M_S"+7"0<C8.4H?__4(N#(````&H!_S#H\,/__X/$(#'`ZYN)]HV\)P````"#
M[`S_-XM<)!CHZL/__XN`2`$``(/$$"4`\```/0!````/A3____^#[`S_-XM<
M)!CHP\/__XM<)!B+@%`!``")1"0LZ%C"__^#Q!`Y1"0<#X41____@^P,_S>+
M7"08Z)7#__^+@$@!``"#Q!`E_P$``#W``0``#X7J_O__@^P,5HM\)!B)^^A]
MPO__B40D+(V'O*#__XGJZ.3L__^#Q!"%P`^$^0$``(/L#%"+7"08Z+S"__]:
M65"+1"0<_S#HOO3__X/$$(7`B<4/A-$!``"#[`Q5BWPD&(G[Z&+"__^#Q!"#
M^`-^*HUT!?R-OQ>A__^Y!0```/.F=1>#^`0/A(X'``"`?`7[+P^$@P<``(UV
M`.A;^?__A<!U'H/L"&H`58M<)!CH*,+__XE$)#"#Q!"%P`^%=`$``(ML)`@Q
M]HV5MZ#__XV]5:'__XV%*Z#__XGKZ'KM___HE<'__U=0C84PH?___W0D(/]T
M)!B-K3ZA__]0:O]J`?]T)#CHH<+__X/$((E\)!"+?"0<ZT&-="8`BUPD".C?
MP?__@S@1=4F+7"0(@\8!Z$;!__^#[`S_="0<5E#_="0P_W0D*%5J_VH!5XM<
M)#CH5L+__X/$,(/L"&C``0``5XM<)!CHB<'__X/$$(/X_W2I@^P,_W0D&(MT
M)!B)\^AOP/__BWPD+(V&U)___XGZZ,;L__^)/"3H'OG__X/$$(GXZ7;]__^-
M="8`@^P,4(E$)!SH`_G__XM$)!R+7"08B00DZ#/!__^#Q!#I3?W__[\!````
MB=CK#6:0BT2\3(/'`87`="N)ZN@>Z___A<!TZH`X`'3E@^P,4(M<)!CH^,#_
M_X/$$(7`=-&)QNG@^O__BU0D"+@-````C;+CH/__Z>#Z__^-M@````"+1"00
MBRCI)/[__VH":O]J[HMT)"Q6BWPD&(G[Z"?`__^#Q`QJ!HV$)#0!``")1"08
M4%;H>+___X/$$("\)"P!````=0Z`O"0M`0``0P^$908``&H`:@!J`/]T)"R+
M7"08Z.*____'A"2``````2-%9\>$)(0`````````QX0DB````(FKS>_'A"2,
M`````````,>$))````#^W+J8QX0DE`````````#'A"28````=E0R$,>$))P`
M````````QX0DH````/#ATL/'A"2D`````````,>$)*@`````````QX0DK```
M``````#'A"2P`````````,>$)+0`````````QX0D^`````````"#Q!"-1"1P
MB40D+(V$)*@```")1"0DC;0F`````(/L!&@`@```_W0D&/]T)"R+7"08Z&^^
M__^#Q!"%P(G&#X[[`0``BXPDF````(N<))P```")\(GUP>`#B??!_1\!R(/[
M``^'O0$``#G!#X>U`0``BXPDH````(N<)*0```")A"28````B?B)Z@^LZ!W!
MZAW'A"2<``````````'(B80DH````(N$).@````1VHF4)*0```"%P`^$60$`
M`+U`````*<4Y[@].[@-$)"2#[`15_W0D&%"+7"08Z.>]__^+A"3X`````>B)
MA"3X````@\00@_A`#X4C____BT0D+"GN`VPD$.@LP___C70F`(/^/P^.&@0`
M`(/N0(GWB70D*(GNP>\&C5\!P>,&`>N+;"0LD(UT)@"+!H/&0(F$)*@```"+
M1L2)A"2L````BT;(B80DL````(M&S(F$)+0```"+1M")A"2X````BT;4B80D
MO````(M&V(F$),````"+1MR)A"3$````BT;@B80DR````(M&Y(F$),P```"+
M1NB)A"30````BT;LB80DU````(M&\(F$)-@```"+1O2)A"3<````BT;XB80D
MX````(M&_(F$).0```")Z.A7PO__.?,/A4____^+="0HP><&*?YJ1%93_W0D
M,(M<)!CH;;W__XFT)/@```"#Q!#I#O[__XVV`````(ML)!#I[_[__XVT)@``
M``"+C"2@````BYPDI````(/!`8/3`.E`_O__@^P,_W0D+(M<)!CH#[[__XN$
M)+````"+G"2H````B[0DK````(N4)+0```")1"0@B=@/K/`#B50D)(/@/XU0
M`<:$!+@```"`@\00@_HX#X^E`@``N#@````IT`-4)"2#^`0/@\L"``"%P'0+
MJ`+&`@`/A8@#``"+?"00BVPD%(B<).<```")^`^LZ!B(A"3@````B?@/K.@0
MB(0DX0```(GX#ZSH"(B$).(```")^(B$).,```")V`^L\!B(A"3D````B=@/
MK/`0B(0DY0```(G8#ZSP"(B$).8```"+1"0LZ!'!__^+="1PBWPD=(V4)`,!
M``")5"0@B=6+5"0(B?$/K/D8C9($H?__B(PD[P````^VP8GQ#ZSY$(B,)/``
M``")\0^L^0B+?"1\B(PD\0```(GQBW0D>(B,)/(```")\0^L^1B(C"3S````
MB?$/K/D0B(PD]````(GQ#ZSY"(N\)(0```"(C"3U````B?&+M"2`````B(PD
M]@```(GQ#ZSY&(B,)/<```")\0^L^1"(C"3X````B?$/K/D(B[PDC````(B,
M)/D```")\8NT)(@```"(C"3Z````B?$/K/D8B(PD^P```(GQ#ZSY$(B,)/P`
M``")\0^L^0B+O"24````B(PD_0```(GQB[0DD````(B,)/X```")\0^L^1B(
MC"3_````B?$/K/D0B(PD``$``(GQ#ZSY"(V\)"L!``"(C"0!`0``B?&-M"3P
M````B(PD`@$``(E\)!")]XG6Z0@```!FD`^V!X/'`8/L#%!6:O]J`56+7"0H
M@\4"Z-2[__^#Q"`Y;"00==N+7"0(QH0D*P$```"-@U6A__]0C8,AH?___W0D
M)/]T)"#_="084&K_:@'_="0XZ)B[__^#Q"#I5_G__XM$)!"+4`2%T@^$<?C_
M_X/L#%*+?"08B50D((G[Z(ZZ__^#Q!"#^`,/AE+X__^+5"00C;\<H?__N04`
M``"-=`+\\Z8/1.KI-?C__XGKZ;C\__^+?"0DN$`````IT(T,%XG"=`TQP,8$
M`0"#P`$YT'+UBT0D+.C6OO__BWPD)+D.````,<#SJ^E$_?__C4H$QP(`````
MQT0"_`````"#X?PIR@'"@^+\@_H$#X(@_?__@^+\,<#'!`$`````@\`$.=!R
M\ND(_?__@+PD+@$``$$/A8WY__^`O"0O`0``0P^%?_G__X"\)#`!``!(#X5Q
M^?__@+PD,0$``$4/A6/Y__]J`FK_:L:+;"0L58M\)!B)^^A"N?__@\0,:BF+
M="085E7HFKC__XV'5:'__U"-AR&A__]6_W0D,/]T)"A0:O]J`?]T)$CH1KK_
M_X/$,.D%^/__C;8`````,>UFB6P"_NEL_/__Z(<$``"-M"8`````55=64^BG
MO/__@<,G90``@^PXBZM,````9:$4````B40D*#'`_W4`Z,RY___&0&4!C40D
M*(E$)!R)PHV##Z#__^@[X___@\00A<!T"8`X,0^$6P(``.@V[O__@^P,_W4`
MZ).Y__^-DT^A__]J"VH!4E#HFKC__X/$((7`#X3`````BT`,@[MX$0```8M`
M&(E$)`0/CJD````Q_[X!````ZS.-M"8`````BT(,@^P(4(N#=!$``/\TL.B+
MM___@\00A<!U;(N#>!$``(/&`8/'`3GP?F*#[`S_=0#H&;G__VH`5_]T)!Q0
MZ-2X__^#Q""%P'0]BQ"+0@@E``0@`#T`!```=*2)5"0(@^P,_W4`Z.6X__]J
M`FH`BU0D(%)0Z*:W__^#Q"#KA(GVC;PG`````(N#>!$``(U0_SGZ#X0G`0``
M@^P,_W4`Z*RX__^-DU2A__]J`VH!4E#HL[?__X/$((7`B<9T,XM`#(/L#(LX
M_W4`Z(*X__^-DU:A__^#Q`Q25U#H.;?__XM&#(/$$(LP]D8*0`^%@`$``(/L
M#/]U`.A4N/__C9-;H/__:@-J`5)0Z%NW__^#Q""%P(G&=#>+5"0,C8/=G___
MZ+/A__^%P(G'#X09`0``BT8,@^P,BS#_=0#H$;C__X/$#%=64.C.MO__@\00
M@^P,_W4`Z/BW__^+5"0<QD!E`(V#U)___^AMX?__@\00A<")QHF#?!$```^$
MF@```(/L"&C``0``5N@TM___C5`!@\00@_H!=@F#^!$/A?(```"+1"0<93,%
M%`````^%W````(/$+%M>7UW#C;0F`````(/X`0^.T/[__XM\)`2^`0```(VV
M`````(/L#/]U`(/&`>AJM___6EE74.CAM?__@\00.;-X$0``?][IFO[__XGV
MC;PG`````(!X`0`/A*#]___IEOW__Y"#[`S_LW01``#HPN___X/$$(7`B<:)
M@WP1```/A47___^-@R2B__^#[`Q0Z&BV__^+@W01``"#[`R+.(M&#(LP_W4`
MZ/"V__^)^HGPZ!_F__^#Q!#IW/[__X/L#/]U`.C4MO__6EE64.ACMO__@\00
MZ63^___H1@$``%"+@W01``!6_S"-@TBB__]0Z`BV__]75E.+="00Z%2Y__^!
MP]1A``"#[`Q6Z#7J__\/MA"#Q!")QX32=!F-0`&-M@````"`^B\/MA`/1/B#
MP`&$TG7PZ-OL__^%]G0@A<!T'(`^`'07C8,)H?__@^P(4%?HCK3__X/$$#GX
M=`1;7E_#6XGP7E_I2>/__XL,),-FD&:0D%/HVKC__X'#6F$``(/L"(V#-`$`
M`(7`=!^+`%#_="0<_W0D'/]T)!SHX[3__X/$&%O#C;8`````,<#KWV:09I!5
M5U93Z)>X__^!PQ=A``"#[`R+;"0@C;,(____Z-.S__^-@P3___\IQL'^`H7V
M="4Q_XVV`````(/L!/]T)"S_="0L5?^4NP3___^#QP&#Q!`Y]W7C@\0,6UY?
M7<.-=@#SPV:09I!FD&:09I!FD&:04^@JN/__@<.J8```@^P(Z`2T__]3@^P(
MZ!.X__^!PY-@``"#Q`A;PP,````!``(`)7,O)7,`+W!R;V,O<V5L9B]E>&4`
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`"]P<F]C+R5I+R5S`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!0
M15),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:
M140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`
M4$%27T%21T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"
M04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"
M04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q)0E!!5$@`1%E,1%],24)205)97U!!
M5$@`4TA,24)?4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%53
M15).04U%`"4P,G@`<&%R+0`E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE
M+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P
M97)L`"UE`"TM`````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M`````'!E<FQX<VDN8P```"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD
M(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````979A;"`G
M97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@
M;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L
M.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL
M93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL
M:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC
M;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@]
M,3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP
M)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE
M97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE
M;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C
M;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC
M;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^
M9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?
M<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A
M;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@/2!M87`@)$5.5GLB4$%2
M7T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*)#`@/2`D
M14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME>7,@)45.5BD@>PID
M96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PI]"GT*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("@D;W5T
M+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PII9B`H)&]U
M="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O
M=70["F-H;6]D(#`W-34L("1F:6QE;F%M93L*?0HD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["FUY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S
M96YA;64D97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["F]P96X@
M;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1O
M=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["GT*96QS92!["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L
M"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]
M"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?
M.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE
M;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*
M;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@
M=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O
M<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O
M)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/
M.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL
M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M
M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E
M('L*;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N
M86UE+3Y[8W)C?2D["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT
M("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@)&]U=#L*?0IO<&5N(&UY
M("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T
M=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@
M9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF
M("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M
M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP
M,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S
M<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C
M;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@
M=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*
M:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@
M0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE
M;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,[
M"G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU
M<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D
M9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E
M("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I
M9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q
M(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q
M)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D
M;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z
M("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#([
M"GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI
M('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I
M<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`
M05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI
M=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U
M="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I
M;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P
M,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I
M;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM
M>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B([
M"F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U
M;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U
M="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD
M+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII
M9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A
M?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I
M"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L
M(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V
M86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H
M)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B
M/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S
M970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<[
M"GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD
M;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM
M>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N
M92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X
M<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@
M0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R
M.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT
M(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R
M96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*
M9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS
M:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>
M+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y
M.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D
M;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL
M97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL
M92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O
M;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB
M=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#
M86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT
M(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI
M.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O
M)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N
M86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I
M*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D
M8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W
M('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U
M+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(
M03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D
M;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T
M>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA
M;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI
M.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P
M96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB
M0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP
M.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!
M4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@
M:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M
M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@
M;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@[
M"FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z
M.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I
M.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M
M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA
M;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI
M.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@
M=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/
M(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D
M,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N
M<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=
M('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D
M,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M
M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M
M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D
M;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A
M=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@
M9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I
M<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*
M<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R
M<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U
M:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N
M9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S
M.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@
M?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4
M:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L
M24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@
M=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD
M<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH
M;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!4
M14U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N
M;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@[
M"FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E
M='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.
M86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D
M<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\
M("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O
M7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB
M+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA
M;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@
M-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#([
M"G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS
M92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG
M97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I
M;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@
M*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U
M+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T
M>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O
M9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*
M8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D[
M"GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY
M("@D97AT+"`D8W)C*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD9FEL
M96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%27T-,
M14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*<'5S
M:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N9&5F
M+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H+"`G
M/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD
M969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!
M345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@
M?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N
M/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O
M+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P
M<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E
M;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@
M7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#
M04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG
M4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'
M("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R
M7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM
M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,
M14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY0
M05)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U
M:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS
M92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@
M0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI
M.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@
M<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O
M9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`!&P,[Z````!P```#X<O__
M!`$``/AT__]P#0``J'C__R@!``!(GO__;`$```B?___0`0``F)___P@"``#8
MH?__B`(``%BC__]``P``^*/__[`#``#(I/__3`0```BE__]\!```:*7__\@$
M```XIO__7`4``$BF__]P!0``.*C__VP&``!HJ/__@`8``%BI___P!@``.*O_
M_R@'``"XJ___3`<``/BK__]X!P``6*W__^P'``#(NO__U`L``!B^__\@#0``
MC[[__[@-``"8OO__S`T``-B^__\`#@``.+___TP.``!(O___8`X``!0`````
M`````7I2``%\"`$;#`0$B`$``"`````<````[''__Q``````#@A&#@Q*#PMT
M!'@`/QH[*C(D(D````!`````>'?__Y4E````00X(A0)!#@R'`T0.$(8$00X4
M@P5&#J`&`WXE"@X40<,.$$'&#@Q!QPX(0<4.!$$+````8````(0```#4G/__
MLP````!!#@B%`D$.#(<#00X0A@1!#A2#!4X.,`)1#C1!#CA$#CQ!#D!(#C!7
M"@X40\,.$$'&#@Q!QPX(0<4.!$(+6@X41<,.$$'&#@Q!QPX(0<4.!````#0`
M``#H````,)W__XH`````00X(AP)!#@R&`T,.$(,$3@X@`FX*#A!!PPX,0<8.
M"$''#@1!"P``?````"`!``"(G?__.0(```!!#@B%`D$.#(<#0PX0A@1!#A2#
M!5`.3%<.4$@.0%D.3$,.4$@.0`)/#DQ-#E!(#D`">`H.%$'##A!!Q@X,0<<.
M"$'%#@1'"P)8#DA!#DQ!#E!,#D!I#DQ+#E!(#D!.#D1!#DA)#DQ%#E!0#D``
M``"T````H`$``$B?__]V`0```$$."(4"00X,AP-!#A"&!$$.%(,%4PZ@`6P*
M#A1!PPX00<8.#$''#@A!Q0X$20M##JP!00ZP`4@.H`%?#JP!00ZP`4@.H`%7
M#JP!00ZP`6L.K`%!#J@!10ZL`4$.L`%$#K0!0@ZX`4(.O`%!#L`!2`ZD`40.
MJ`%!#JP!0@ZP`4@.H`%8#JP!00ZP`4@.H`%##JP!00ZP`4@.H`%P#JP!00ZP
M`5`.H`$`;````%@"```0H/__F`````!!#@B'`D$.#(8#0PX0@P1.#AQ(#B!(
M#A1&#AA!#AQ"#B!(#A!%"L,.#$/&#@A!QPX$0PM##AQ"#B!.#A!/#AQ"#B!.
M#A!/#AA"#AQ!#B!(#A!&PPX,1,8."$''#@0``)@```#(`@``0*#__]``````
M00X(A0)!#@R'`T,.$(8$00X4@P51#L0@6`[(($L.S"!!#M`@2`[`(%,.Q"!!
M#L@@0@[,($$.T"!(#L`@30[,($(.T"!&#M0@00[8($$.W"!!#N`@2`[`(%8*
M#A1!PPX00<8.#$''#@A!Q0X$1`M1#LP@0@[0($@.Q"!$#L@@00[,($$.T"!(
M#L`@`"P```!D`P``=*#__SL`````00X(@P).#AQ(#B!,#B1,#BA!#BQ!#C!(
M#@A!PPX$`$@```"4`P``A*#__U,`````00X(A@)!#@R#`TX.'$@.($X.'$(.
M($8.'$<.&$(.'$$.($$.)$<.*$<.+$$.,$@.#$'##@A!Q@X$``"0````X`,`
M`)B@___)`````$$."(4"00X,AP-!#A"&!$$.%(,%40ZP0%T.N$!!#KQ`00[`
M0$<.Q$!%#LA`0@[,0$4.T$!(#K!`1PZT0$4.N$!(#KQ`00[`0$@.L$!,#KQ`
M00[`0$@.L$!)#K1`00ZX0$$.O$!!#L!`3`ZP0%@*#A1!PPX00<8.#$''#@A!
MQ0X$2PL`$````'0$``#4H/__!0````````#X````B`0``-"@___O`0```$$.
M"(4"00X,AP-!#A"&!$$.%(,%40[0(&\.V"!$#MP@00[@($@.T"!M"@X40<,.
M$$'&#@Q!QPX(0<4.!$$+0P[<($$.X"!&#MP@00[8($\.W"!!#N`@2`[0('D.
MV"!!#MP@00[@($@.T"!+#MP@00[@($@.T"!U#M0@1`[8($$.W"!'#N`@00[D
M($4.Z"!"#NP@10[P($@.W"!&#N`@2`[4($8.V"!!#MP@0@[@($@.T"!'#MP@
M1@[@($X.T"!/#M@@00[<($(.X"!(#M`@5@[8($(.W"!!#N`@2`[0(%0.W"!!
M#N`@2`[0(``0````A`4``,2A__\B`````````&P```"8!0``X*'__^@`````
M00X(A@)!#@R#`TX.(%8.+$$.,$P.(&`.+$(.,$@.($\*#@Q!PPX(0<8.!$(+
M7@XL00XP2`X@:@XD00XH00XL1PXP2`X@10H.#$'##@A!Q@X$1PM##@Q#PPX(
M0<8.!``T````"`8``&"B___9`0```$$."(<"00X,A@-!#A"#!$X.0`-V`0H.
M$$'##@Q!Q@X(0<<.!$8+`"````!`!@``"*3__WD`````00X(@P).#B!G"@X(
M0<,.!$D+`"@```!D!@``9*3__S0`````00X(@P).#A!(#AQ!#B!(#A!)"@X(
M0<,.!$8+<````)`&``!XI/__6@$```!!#@B%`D$.#(<#00X0A@1!#A2#!4X.
M<`*!#GA$#GQ!#H`!3`YP`D8*#A1!PPX00<8.#$''#@A!Q0X$0@M##GQ$#H`!
M;`YT10YX1`Y\1`Z``40.A`%"#H@!0@Z,`4$.D`%,#G#D`P``!`<``&2E__]I
M#0```$$."(4"00X,AP-!#A"&!$$.%(,%40[0@@("Q`[<@@)!#N""`E`.T(("
M0P[<@@)!#N""`E`.T((":`[<@@)$#N""`D$.Y(("0@[H@@)"#NR"`D$.\(("
M3P[0@@("0`[<@@)!#N""`DP.T(("`D(.W(("00[@@@),#M""`E(.W(("00[@
M@@),#M""`GT.W(("2`[@@@)-#N2"`D\.Z(("2P[L@@)'#O""`D$.](("0@[X
M@@)"#OR"`D4.@(,"2`[8@@)%#MR"`D0.X(("2`[0@@),#MR"`DX.X(("3`[4
M@@)&#MB"`D0.W(("0@[@@@),#M""`DL.W(("1`[@@@)&#N2"`DL.Z(("2`[L
M@@)"#O""`D@.T(("7`H.%$'##A!!Q@X,0<<."$'%#@1("U,.V(("00[<@@)$
M#N""`D8.Y(("2P[H@@)(#NR"`D(.\(("2`[0@@)0#MR"`D(.X(("4@[0@@)3
M#MR"`D(.X(("7P[0@@)-#MR"`D(.X(("4@[0@@)3#MR"`D$.X(("7P[0@@)+
M#MR"`D$.X(("2@[<@@)!#MB"`D$.W(("1@[@@@)(#M""`DT.W(("00[@@@).
M#M""`GL.V(("0@[<@@)!#N""`E`.T((";0[4@@)!#MB"`DH.W(("1`[@@@)'
M#N2"`D(.Z(("0@[L@@)$#O""`D@.T((":P[<@@)$#N""`D$.Y(("00[H@@)$
M#NR"`D0.\(("00[T@@)"#OB"`D(._(("00Z`@P),#M""`D,.V(("10[<@@)!
M#N""`DP.T(("2`[<@@)$#N""`F<.T(("3@[<@@)!#N""`EP.T((";@[<@@)!
M#N""`DP.T(("<@[4@@)"#MB"`D(.W(("10[@@@).#M2"`D(.V(("3`[<@@)!
M#N""`D@.T(("6@[4@@)"#MB"`D(.W(("1`[@@@("L0[0@@)=#M2"`D4.V(("
M1`[<@@)$#N""`DP.T(("`I8.U(("00[8@@)$#MR"`D$.X(("7`[0@@(#``$.
MU(("00[8@@)!#MR"`D0.X(("4P[0@@)W#MR"`D0.X(("`D0.T(("`P4"#MR"
M`D$.X(("00[D@@)"#NB"`D(.[(("00[P@@)/#M""`ED.U(("2@[8@@)$#MR"
M`D0.X(("00[D@@)"#NB"`D(.[(("1`[P@@)(#M""`E<.W(("00[@@@)2#M""
M`@+=#M2"`D(.V(("0@[<@@)%#N""`DX.U(("0@[8@@)%#MR"`D$.X(("3`[D
M@@)'#NB"`D0.[(("1`[P@@)!#O2"`D(.^(("0@[\@@)$#H"#`D@.T(("2`$`
M`.P*``#LKO__4`,```!!#@B%`D$.#(<#00X0A@1!#A2#!4X.3%4.4&$.0%4.
M3$,.4$T.5$(.6$$.7$$.8$@.0'4.2$$.3$D.4$@.0%<.3$,.4$<.5$$.6$0.
M7$$.8$@.0%P.3$,.4$<.5$(.6$4.7$$.8$@.0%\.3$,.4$T.5$(.6$$.7$$.
M8$@.0$P.3$4.4$X.1$$.2$$.3$$.4$L.0$\.3$,.4$T.5$(.6$$.7$$.8$@.
M0&4.3$4.4$@.1$$.2$$.3$$.4$@.0$,.3$,.4%L.0%,.2$4.3$$.4$L.0&(*
M#A1!PPX00<8.#$''#@A!Q0X$2`M;#DQ##E!)#DQ!#DA!#DQ!#E!(#D!I"@Y,
M1@Y02`Y`60Y,00Y010M)#DQ*#E!1#D!(#DQ##E!&#DQ!#DA!#DQ!#E!(#D!+
M#D1'#DA"#DQ'#E````!,````.`P``/"P__]W`````$$."(<"00X,A@-!#A"#
M!%(.'$$.($L.$'H.&$$.'$$.($@.$$4*PPX,0<8."$''#@1!"T'##@Q#Q@X(
M0<<.!$0```"(#```@&?__T`"````1`P!`$<0!0)U`$8/`W5P!A`'`G5\$`8"
M=7@0`P)U=`-[`0K!#`$`0<-!QD''0<5##`0$00L``!````#0#```S[#__P0`
M````````,````.0,``#$L/__/`````!!#@B#`DX.$$T.%$0.&$0.'$0.($@.
M"$'##@1'#A"#`@```$@````8#0``T+#__UT`````00X(A0)!#@R'`T$.$(8$
M00X4@P5.#B!I#B1$#BA$#BQ!#C!-#B!'#A1!PPX00<8.#$''#@A!Q0X$```0
M````9`T``.2P__\"`````````!@```!X#0``X+#__Q0`````00X(@P).#A``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````$`7``#P
M%@````````$````!`````0```-,!```!````(@(```P```"D$0``#0```#1>
M```9````U+T``!L````$````&@```-B]```<````!````/7^_V^L`0``!0``
M`.P(```&````C`(```H```#C!```"P```!`````5``````````,```#0O@``
M$0```#P/```2````:`(``!,````(````&`````````#[__]O`0``"/[__V^<
M#@``____;P(```#P__]OT`T``/K__V\%````````````````````````````
M`````````````````````````````."]````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````-`3````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````!,```/____]<80``1T-#.B`H56)U;G1U(#4N,RXQ
M+3(Q=6)U;G1U,3$I(#4N,RXQ(#(P,38P-3(X`$=#0SH@*%5B=6YT=2`U+C,N
M,2TQ-'5B=6YT=3(I(#4N,RXQ(#(P,38P-#$S```N<VAS=')T86(`+FEN=&5R
M<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N
M<F5L+F1Y;@`N:6YI=``N<&QT`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A
M=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?
M87)R87D`+FIC<@`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````````
M```````````````````````````````````````````````+`````0````(`
M``!4`0``5`$``!,```````````````$`````````$P````<````"````:`$`
M`&@!```@```````````````$`````````"$````'`````@```(@!``"(`0``
M)```````````````!``````````T````]O__;P(```"L`0``K`$``.`````%
M``````````0````$````/@````L````"````C`(``(P"``!@!@``!@````$`
M```$````$````$8````#`````@```.P(``#L"```XP0``````````````0``
M``````!.````____;P(```#0#0``T`T``,P````%``````````(````"````
M6P```/[__V\"````G`X``)P.``"@````!@````(````$`````````&H````)
M`````@```#P/```\#P``:`(```4`````````!`````@```!S`````0````8`
M``"D$0``I!$``",```````````````0`````````>0````$````&````T!$`
M`-`1```0```````````````0````!````'X````!````!@```.`1``#@$0``
MZ`$`````````````"`````````"'`````0````8```#0$P``T!,``&1*````
M`````````!``````````C0````$````&````-%X``#1>```4````````````
M```$`````````),````!`````@```$A>``!(7@``D$``````````````!```
M``````";`````0````(```#8G@``V)X``.P```````````````0`````````
MJ0````$````"````Q)\``,2?``"4#0`````````````$`````````+,````.
M`````P```-2]``#4K0``!```````````````!`````````"_````#P````,`
M``#8O0``V*T```0```````````````0`````````RP````$````#````W+T`
M`-RM```$```````````````$`````````-`````&`````P```."]``#@K0``
M\`````8`````````!`````@```""`````0````,```#0O@``T*X``#`!````
M``````````0````$````V0````$````#`````,````"P```0````````````
M```$`````````-\````(`````P```"#````0L```-!``````````````(```
M``````#D`````0```#``````````$+```%L```````````````$````!````
H`0````,``````````````&NP``#M```````````````!````````````
